==> edge-login-ui-rn-2.6.0.tgz: package/lib/hooks/useLocalUsers.js <==
import * as React from 'react';
import { useSelector } from '../types/ReduxTypes';
import { getKeychainStatus } from '../util/keychainFile';
import { useImports } from './useImports';
import { useWatch } from './useWatch';
export function useLocalUsers() {
    const { context } = useImports();
    const localUsers = useWatch(context, 'localUsers');
    const touch = useSelector(state => state.touch);
    return React.useMemo(() => arrangeUsers(localUsers).map(info => upgradeUser(info, touch)), [localUsers, touch]);
}
/**
 * Given a list of users from the core,
 * organize the 3 most recent users,
 * followed by the rest in alphabetical order.
 */
export function arrangeUsers(localUsers) {
    // Sort the users according to their last login date:
    const sortedUsers = localUsers.sort((a, b) => {
        const { lastLogin: aDate = new Date(0) } = a;
        const { lastLogin: bDate = new Date(0) } = b;
        return bDate.valueOf() - aDate.valueOf();
    });
    // Get the most recent 3 users that were logged in:
    const recentUsers = sortedUsers.slice(0, 3);
    // Sort everything after the last 3 entries alphabetically:
    const oldUsers = sortedUsers.slice(3).sort((a, b) => {
        var _a, _b, _c, _d;
        const stringA = (_b = (_a = a.username) === null || _a === void 0 ? void 0 : _a.toLowerCase()) !== null && _b !== void 0 ? _b : '';
        const stringB = (_d = (_c = b.username) === null || _c === void 0 ? void 0 : _c.toLowerCase()) !== null && _d !== void 0 ? _d : '';
        if (stringA < stringB)
            return -1;
        if (stringA > stringB)
            return 1;
        return 0;
    });
    return [...recentUsers, ...oldUsers];
}
export function upgradeUser(userInfo, touch) {
    const { username, keyLoginEnabled } = userInfo;
    return Object.assign(Object.assign({}, userInfo), { touchLoginEnabled: username != null &&
            keyLoginEnabled &&
            touch.supported &&
            typeof getKeychainStatus(touch.file, userInfo) === 'string' });
}

==> edge-login-ui-rn-2.12.0.tgz: package/lib/hooks/useLocalUsers.js <==
import * as React from 'react';
import { useSelector } from '../types/ReduxTypes';
import { getKeychainStatus } from '../util/keychainFile';
import { useImports } from './useImports';
import { useWatch } from './useWatch';
export function useLocalUsers() {
    const { context } = useImports();
    const localUsers = useWatch(context, 'localUsers');
    const touch = useSelector(state => state.touch);
    return React.useMemo(() => arrangeUsers(localUsers).map(info => upgradeUser(info, touch)), [localUsers, touch]);
}
/**
 * Given a list of users from the core,
 * organize the 3 most recent users,
 * followed by the rest in alphabetical order.
 */
export function arrangeUsers(localUsers) {
    // Sort the users according to their last login date:
    const sortedUsers = localUsers.sort((a, b) => {
        const { lastLogin: aDate = new Date(0) } = a;
        const { lastLogin: bDate = new Date(0) } = b;
        return bDate.valueOf() - aDate.valueOf();
    });
    // Get the most recent 3 users that were logged in:
    const recentUsers = sortedUsers.slice(0, 3);
    // Sort everything after the last 3 entries alphabetically:
    const oldUsers = sortedUsers.slice(3).sort((a, b) => {
        var _a, _b, _c, _d;
        const stringA = (_b = (_a = a.username) === null || _a === void 0 ? void 0 : _a.toLowerCase()) !== null && _b !== void 0 ? _b : '';
        const stringB = (_d = (_c = b.username) === null || _c === void 0 ? void 0 : _c.toLowerCase()) !== null && _d !== void 0 ? _d : '';
        if (stringA < stringB)
            return -1;
        if (stringA > stringB)
            return 1;
        return 0;
    });
    return [...recentUsers, ...oldUsers];
}
export function upgradeUser(userInfo, touch) {
    const { keyLoginEnabled } = userInfo;
    return Object.assign(Object.assign({}, userInfo), { touchLoginEnabled: keyLoginEnabled &&
            touch.supported &&
            typeof getKeychainStatus(touch.file, userInfo) === 'string' });
}
